LuaStackable

Trait LuaStackable 

pub trait LuaStackable {
    // Required method
    fn get_pos(&self) -> Index;
}
Any value that can represent an Index on a Lua Stack

Required Methods

fn get_pos(&self) -> Index

Get the position of this value on the stack

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors